==> 0.0.1%2B1.tar.gz: lib/models/IR5TblBtn.dart <==
// --------------------------------------------------------------------------------

import 'package:json_annotation/json_annotation.dart';

part 'IR5TblBtn.g.dart';

/** Restaurant Tables */
@JsonSerializable()
class IR5TblBtn {
  IR5TblBtn({
    required this.TblNum,
    required this.BtnNum,
    required this.ObjectType,
    required this.GotoSalle,
    required this.Bmp,
    required this.Angle,
    required this.Shape,
    required this.Top,
    required this.Left,
    required this.Height,
    required this.Width,
    required this.Svc_Top,
    required this.Svc_Left,
    required this.Svc_Height,
    required this.Svc_Width,
  });

  /** If BtnNum==TblNum --> TblBtn Normal */

  /** If BtnNum<>TblNum --> Btn est un alias vers TblNum */
  @JsonKey(defaultValue: '')
  final String TblNum;
  @JsonKey(defaultValue: '')
  final String BtnNum;

  /** Default ObjectType = tblTrueTbl */

  /** Table ObjectTypes
   *
   * 10 - <<<Table>>>
   * 11 - Alias
   * 12 - Members
   * 21 - Image
   * 20 - Image + Texte
   * 40 - Porte
   * 41 - Porte + Texte
   * 43 - Salles List
   * 44 - All Salles List
   * 42 - MiniSalle
   * 45 - WebView
   * 50 - Total Service
   * 98 - <<<Missing POS Table>>>
   * 1 - <<<Table>>>
   * 97 - <<<Missing Member Table>>>
   * 99 - <<<Missing Table>>>
   */
  @JsonKey(defaultValue: 0)
  final num ObjectType;
  @JsonKey(defaultValue: '')
  final String GotoSalle;

  /** GUI Params. */
  /** Image Num */
  @JsonKey(defaultValue: 0)
  final num Bmp;
  @JsonKey(defaultValue: 0)
  final num Angle;
  @JsonKey(defaultValue: '')
  final String Shape;
  @JsonKey(defaultValue: 0)
  final num Top;
  @JsonKey(defaultValue: 0)
  final num Left;
  @JsonKey(defaultValue: 0)
  final num Height;
  @JsonKey(defaultValue: 0)
  final num Width;
  @JsonKey(defaultValue: 0)
  final num Svc_Top;
  @JsonKey(defaultValue: 0)
  final num Svc_Left;
  @JsonKey(defaultValue: 0)
  final num Svc_Height;
  @JsonKey(defaultValue: 0)
  final num Svc_Width;

  factory IR5TblBtn.fromJson(Map<String, dynamic>? json) => _$IR5TblBtnFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5TblBtnToJson(this);
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5TblBtn.dart <==
// --------------------------------------------------------------------------------

import 'package:json_annotation/json_annotation.dart';

part 'IR5TblBtn.g.dart';

/** Restaurant Tables */
@JsonSerializable()
class IR5TblBtn {
  IR5TblBtn({
    required this.TblNum,
    required this.BtnNum,
    required this.ObjectType,
    required this.GotoSalle,
    required this.Bmp,
    required this.Angle,
    required this.Shape,
    required this.Top,
    required this.Left,
    required this.Height,
    required this.Width,
    required this.Svc_Top,
    required this.Svc_Left,
    required this.Svc_Height,
    required this.Svc_Width,
  });

  /** If BtnNum==TblNum --> TblBtn Normal */

  /** If BtnNum<>TblNum --> Btn est un alias vers TblNum */
  @JsonKey(defaultValue: '')
  final String TblNum;
  @JsonKey(defaultValue: '')
  final String BtnNum;

  /** Default ObjectType = tblTrueTbl */

  /** Table ObjectTypes
   *
   * 10 - <<<Table>>>
   * 11 - Alias
   * 12 - Members
   * 21 - Image
   * 20 - Image + Texte
   * 40 - Porte
   * 41 - Porte + Texte
   * 43 - Salles List
   * 44 - All Salles List
   * 42 - MiniSalle
   * 45 - WebView
   * 50 - Total Service
   * 98 - <<<Missing POS Table>>>
   * 1 - <<<Table>>>
   * 97 - <<<Missing Member Table>>>
   * 99 - <<<Missing Table>>>
   */
  @JsonKey(defaultValue: 0)
  final num ObjectType;
  @JsonKey(defaultValue: '')
  final String GotoSalle;

  /** GUI Params. */
  /** Image Num */
  @JsonKey(defaultValue: 0)
  final num Bmp;
  @JsonKey(defaultValue: 0)
  final num Angle;
  @JsonKey(defaultValue: '')
  final String Shape;
  @JsonKey(defaultValue: 0)
  final num Top;
  @JsonKey(defaultValue: 0)
  final num Left;
  @JsonKey(defaultValue: 0)
  final num Height;
  @JsonKey(defaultValue: 0)
  final num Width;
  @JsonKey(defaultValue: 0)
  final num Svc_Top;
  @JsonKey(defaultValue: 0)
  final num Svc_Left;
  @JsonKey(defaultValue: 0)
  final num Svc_Height;
  @JsonKey(defaultValue: 0)
  final num Svc_Width;

  factory IR5TblBtn.fromJson(Map<String, dynamic>? json) =>
      _$IR5TblBtnFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5TblBtnToJson(this);
}
